unit FortressCommonDefs;

interface

uses Sysutils, classes, windows;

const
  MaxTurnTime     = 20000 ; // in milliseconds

  MaxProjectsToPLayer    = 15;
  TotalProjectsCount     = 50;
  BotNameMaxLength       = 30;

  BlockShieldValue = 20;  //       

  BaseLabLimit     = 5;   //    
  UnlimitLabsBaseValue  = 50;   //         
  UnlimitLabsStep       = 5;    //

 {
        
    LabLimit = ((Base-UnlimitLabsBaseValue) div UnlimitLabsStep) + BaseLabLimit
  }  

  HUMAN_NAME = '_HUMAN_';
type

  TPlayerInfo = record
    Base:integer;    // 
    Shield:integer;  // 
    Battery:integer; // +   
    Mines:integer;   // +   
    Labs:integer;    // +   

    Energy:integer;  //   
    Metal:integer;   //   
    Elements:integer;//   
   end;

  TGame = array[0..1] of TPlayerInfo;
  PGame = ^ TGame;

  TAvailProjects = array[0..MaxProjectsToPlayer-1] of integer;
  PAvailProjects = ^ TAvailProjects;

  TAdditionalGameInfo = record
    PreviousOpponentProject: integer;
    TurnCount: integer;
    PlrMessage: DWORD;
    GameFlags: DWORD;
    OpponentName: array[0..BotNameMaxLength] of char;
    GameResult: DWORD;
    Reserved:DWORD;
   end;

  PAdditionalGameInfo = ^ TAdditionalGameInfo;

  TGetBotNameFunc  = function:PChar; stdcall;

  TStartGameFunc  = function(aPlayerNumber:integer; aAvailProjects: PAvailProjects;
    AGI:PAdditionalGameInfo):integer; stdcall;
  TPlayerTurnFunc  = function(aPlayerNumber:integer; aGame:PGame; aAvailProjects: PAvailProjects;
    AGI:PAdditionalGameInfo):integer;  stdcall;

const
   //GameFlags
  GF_EXTENDED     = $00010000;
  GF_BOT_vs_BOT   = $10000000;
  GF_SHOWGAMERESULT=$20000000;

  //GameResult
  GR_FirstLose    = $00000001;
  GR_SecondLose   = $00000002;
  GR_Draw         = $00000004;
  GR_WIN          = $00000008;  //

  GR_ERROR        = $00000010;
  GR_TimeOut      = $00000020;

  
  ProjectsData:array[1..TotalProjectsCount,1..3] of integer=
  ({En,Me,El}
   {Attack}
   (4,0,0),
   (0,4,0),
   (0,0,5),
   (5,3,0),
   (3,5,0),
   (1,2,5),
   (0,9,3),
   (3,8,0),
   (2,3,7),
   {Attack2}
   (9,4,2),
   (5,8,2),
   (10,5,2),
   (10,5,2),
   (6,9,3),
   {Repair}
   (5,0,0),
   (9,0,2),
   (14,0,3),
   (0,7,2),
   (5,4,0),
   (0,8,5),
   (0,5,10),
   (16,14,0),
   {SpecAttack}
   (0,2,2),
   (3,3,5),
   (2,5,3),   
   (4,0,3),
   (0,3,4),
   {SuperAttack}
   (17,5,0),
   (16,14,6),
   (18,12,2),
   (26,16,10),
   (16,12,6),
   {Development}
   (2,4,9),
   (6,4,5),
   (4,9,2),
   (9,9,14),
   (4,15,4),
   (16,0,0),
   (4,0,0),
   (6,0,0),
   {Espoinage}
   (5,0,5),
   (5,5,0),
   (4,5,7),
   (6,2,12),
   (2,6,12),
   (3,7,17),
   (8,4,20),
   (12,4,20),
   (4,5,20),
   (0,0,0)
   ); //  

  ProjectsStrings:array[1..TotalProjectsCount] of string =
  (
   '(1)  1. En 4 : ->5',
   '(2)  2. Me 4 : ->5',
   '(3)  3. El 5 : ->5',
   '(4)  4. En 5, Me 3 : ->7',
   '(5)  5. En 3, Me 5 : ->8',
   '(6)  6. En 1, Me 2, El 5 : ->8',
   '(7)  7. En 9, Me 3 : ->10',
   '(8)  8. En 3, Me 8 : ->10',
   '(9)  9. En 2, Me 3, El 7 : ->10',
   '(10) 2 1. En 9, Me 4, El 2 : ->14',
   '(11) 2 2. En 5, Me 8, El 2 : ->15',
   '(12) 2 3. En 10, Me 5, El 2  : ->25, <-10',
   '(13) 2 4. En 10, Me 5, El 2 : ->17',
   '(14) 2 5. En 6, Me 9, El 3 : ->18',
   '(15)  1. En 5 : SS+6',
   '(16)  2. En 9, El 2 : SS+10',
   '(17)  2. En 14, El 3 : SS+15',
   '(18)  3. Me 7, El 2 : SB+9',
   '(19)  4. En 5, Me 4 :      ,   2:1 (   6  )',
   '(20)  5. Me 8, El 5 : SB+12',
   '(21)  6. Me 5, El 10 : SB+14',
   '(22)  7. En 16, Me 14 : SS+15, SB+12',
   '(23)  1. Me 2, El 2 : Base-3',
   '(24)  2. En 3, Me 3, El 5 : Base-7',
   '(25)  2. En 2, Me 5, El 3 : Base-7',
   '(26)  3. En 4, El 3 :   ( 7 )        1+2*(-  )',
   '(27)  4. Me 3, El 4 :     0,  Base-11',
   '(28)  1. En 17, Me 5 : Base-10, Shield-10',
   '(29)  2. En 16, Me 14, El 6 : Base-20, Shield-15',
   '(30)  3. En 18, Me 12, El 2 : ->49, <-20',
   '(31)  4. En 26, Me 16, El 10 : ->49',
   '(32)  5. En 16, Me 12, El 6: ->25, Base-5',
   '(33)  1. En 2, Me 4, El 9 : +1',
   '(34)  2. En 6, Me 4, El 5 : +1',
   '(35)  3. En 4, Me 9, El 2 : +1',
   '(36)  4. En 9, Me 9, El 14 : +1, +1',
   '(37)  5. En 4, Me 15, El 4 : +1, SB+7',
   '(38)  6. En 16 :   10    ,   1 Me = 2 El',
   '(39)  7. En 4 :   10    .',
   '(40)  8. En 6 :   12    .',
   '(41)  1. En 5, El 5 :   5    ',
   '(42)  2. En 5, Me 5 :   5    ',
   '(43)  3. En 4, Me 5, El 7 : Shield-7,    7,    5  ',
   '(44)  4. En 6, Me 2, El 12 :     2- ,  -1 ',
   '(45)  5. En 2, Me 6, El 12 :     3- ,  -1 ',
   '(46)  6. En 8, Me 7, El 17 : ->15,       ',
   '(47)  7. En 8, Me 4, El 20 :     15 ,    15  ,  Shield-15    15    ',
   '(48)  8. En 12, Me 4, El 20 :     15 ,    15  ,  Base-15    15    ',
   '(49)  9. En 4, Me 5, El 20 : Shield-10,    10,    15 ',
   '(50)  '
   );

function GetOtherPlayer(aPlayer:integer):integer;
function IsFlagPresented(value:DWORD;aFlag:DWORD):boolean;

implementation

function GetOtherPlayer(aPlayer:integer):integer;
begin
  Result:=0;
  if aPlayer=0 then Result:=1;
end;

function IsFlagPresented(value:DWORD;aFlag:DWORD):boolean;
begin
  Result:= (value and aFlag) = aFlag;
end;




end.

